From: Michal Privoznik <mprivozn(a)redhat.com>
The script is renamed to mock-noipa.py and adjusted to check for
the new attribute.
Signed-off-by: Michal Privoznik <mprivozn(a)redhat.com>
---
build-aux/syntax-check.mk | 4 ++--
scripts/meson.build | 2 +-
scripts/{mock-noinline.py => mock-noipa.py} | 6 +++---
3 files changed, 6 insertions(+), 6 deletions(-)
rename scripts/{mock-noinline.py => mock-noipa.py} (93%)
diff --git a/build-aux/syntax-check.mk b/build-aux/syntax-check.mk
index d414e033df..16a28241db 100644
--- a/build-aux/syntax-check.mk
+++ b/build-aux/syntax-check.mk
@@ -1326,9 +1326,9 @@ sc_spacing-check:
$(PERL) $(top_srcdir)/build-aux/check-spacing.pl || \
{ echo 'incorrect formatting' 1>&2; exit 1; }
-sc_mock-noinline:
+sc_mock-noipa:
$(AM_V_GEN)$(VC_LIST_EXCEPT) | $(GREP) '\.[ch]$$' | $(RUNUTF8) \
- $(PYTHON) $(top_srcdir)/scripts/mock-noinline.py
+ $(PYTHON) $(top_srcdir)/scripts/mock-noipa.py
sc_header-ifdef:
$(AM_V_GEN)$(VC_LIST_EXCEPT) | $(GREP) '\.[h]$$' | $(RUNUTF8) xargs \
diff --git a/scripts/meson.build b/scripts/meson.build
index 2798e302ab..bc38277dbf 100644
--- a/scripts/meson.build
+++ b/scripts/meson.build
@@ -29,7 +29,7 @@ scripts = [
'meson-install-web.py',
'meson-python.sh',
'meson-timestamp.py',
- 'mock-noinline.py',
+ 'mock-noipa.py',
'prohibit-duplicate-header.py',
'qemu-replies-tool.py',
]
diff --git a/scripts/mock-noinline.py b/scripts/mock-noipa.py
similarity index 93%
rename from scripts/mock-noinline.py
rename to scripts/mock-noipa.py
index 77a5ca23e2..66a5f38bdc 100755
--- a/scripts/mock-noinline.py
+++ b/scripts/mock-noipa.py
@@ -22,7 +22,7 @@ import sys
noninlined = {}
mocked = {}
# Functions in public header don't get the noinline annotation
noninlined["virEventAddTimeout"] = True
# This one confuses the script as its defined in the mock file
# but is actually just a local helper
@@ -43,7 +43,7 @@ def scan_annotations(filename):
elif line.isspace():
func = None
- if "G_NO_INLINE" in line:
+ if "ATTRIBUTE_NOIPA" in line:
if func is not None:
noninlined[func] = True
@@ -74,7 +74,7 @@ warned = False
for func in mocked.keys():
if func not in noninlined:
warned = True
- print("%s is mocked at %s but missing 'G_NO_INLINE' annotation"
%
+ print("%s is mocked at %s but missing 'ATTRIBUTE_NOIPA'
annotation" %
(func, mocked[func]), file=sys.stderr)
if warned:
@@ -22,7 +22,7 @@ import sys
noninlined = {}
mocked = {}
-# Functions in public header don't get the noinline annotation
+# Functions in public header don't get the noipa annotation
noninlined["virEventAddTimeout"] = True
# This one confuses the script as its defined in the mock file
--
2.49.0